<?php

require_once('ApiSettings.php');
require_once('DataCenterVisitor.php');

/**
 * This is the API endpoint for the ColocationService
 *
 * @package Transip
 * @class ColocationService
 * @author TransIP (support@transip.nl)
 * @version 20090811 08:04
 */
class Transip_ColocationService
{
	// These fields are SOAP related
	const WSDL = 'https://80.69.67.65/wsdl/?service=ColocationService';
	protected static $_soapClient = null;

	/**
	 * Gets the singleton SoapClient which is used to connect to the  TransIP Api
	 *
	 * @return SoapClient the SoapClient object to which we can connect to the TransIP API
	 */
	public static function _getSoapClient()
	{
		if(is_null(self::$_soapClient))
		{
			$classMap = array(
				'DataCenterVisitor' => 'Transip_DataCenterVisitor',
			);

			$options = array(
				'classmap'  => $classMap,
				'encoding' => 'utf-8', // lets support unicode
				'features' => SOAP_SINGLE_ELEMENT_ARRAYS, // see http://bugs.php.net/bug.php?id=43338
				'trace' => false, // can be used for debugging
			);

			self::$_soapClient = new SoapClient(self::WSDL, $options);

			self::$_soapClient->__setCookie('login', Transip_ApiSettings::$login);
			self::$_soapClient->__setCookie('hash', Transip_ApiSettings::$hash);
			self::$_soapClient->__setCookie('mode', Transip_ApiSettings::$mode);
		}

		return self::$_soapClient;
	}

	/**
	 * Requests access to the data-center
	 *
	 * @param string $when the datetime of the wanted datacenter access, in YYYY-MM-DD hh:mm:ss format
	 * @param int $duration the expected duration of the visit, in minutes
	 * @param string[] $visitors the names of the visitors for this data-center visit, must be at least 1 and at most 20
	 * @param string $phoneNumber if an SMS with access codes needs to be sent, set the phonenumber of the receiving phone here;
	 * @return Transip_DataCenterVisitor[] An array of Visitor objects holding information (such as reservation and access number) about
	 */
	public static function requestAccess($when, $duration, $visitors, $phoneNumber)
	{
		return self::_getSoapClient()->requestAccess($when, $duration, $visitors, $phoneNumber);
	}
}

?>
