<?php

/**
 * This class models a Domain
 *
 * @package Transip
 * @class Domain
 * @author TransIP (support@transip.nl)
 * @version 20090811 08:04
 */
class Transip_Domain
{
	/**
	 * The name, including the tld of this domain
	 *
	 * @var string
	 */
	public $name = '';

	/**
	 * The list of nameservers (with optional gluerecords) for this domain
	 *
	 * @var Transip_Nameserver[]
	 */
	public $nameservers = array();

	/**
	 * The list of WhoisContacts for this domain
	 *
	 * @var Transip_WhoisContact[]
	 */
	public $contacts = array();

	/**
	 * The list of DnsEntries for this domain
	 *
	 * @var Transip_DnsEntry[]
	 */
	public $dnsEntries = array();

	/**
	 * The branding for this domain, some Tlds support additional
	 * whois- and transfer-branding which will be stored in this variable.
	 * Even if a Tld does not support  branding, it will
	 * always be stored in this variable for consistency.
	 *
	 * @var Transip_DomainBranding
	 */
	public $branding;

	/**
	 * Constructs a new Domain
	 *
	 * @param string $name the domain name of the domain, including tld
	 * @param Nameserver[] $nameservers the list of nameservers (with optional gluerecords) for this domain
	 * @param WhoisContact[] $contacts the list of WhoisContacts for this domain
	 * @param DnsEntry[] $dnsEntries the list of DnsEntries for this domain
	 * @param DomainBranding $branding the branding for this domain, see the branding property for more info
	 */
	public function __construct($name, $nameservers=array(), $contacts=array(), $dnsEntries=array(), $branding=null)
	{
		$this->name			= $name;
		$this->nameservers	= $nameservers;
		$this->contacts 	= $contacts;
		$this->dnsEntries	= $dnsEntries;
		$this->branding 	= $branding;
	}
}

?>
